/****************************************************/
/*      BIBLIOTECA DE MANEJO DEL RATON              */
/*     ANGEL PEDRERA PLATA. 13/05/00.               */
/****************************************************/

#include <dos.h>
char visualizado; /*Indica si el raton esta o no visualizado*/

/*****************************************************/
/*  Objetivo: Inicializar el raton.                  */
/*Devuelve el numero de botones que tiene.           */
/*  -1 -->ERROR No hay raton o controlador.          */
/*   0 -->Tiene 1 o mas de tres botones              */
/*   2 --> Dos botones compatibles con microsoft     */
/*   3 --> Tres botones del estandar Logitech        */
/*  65535 -->2 botones ccno compatibles con MS       */
/*****************************************************/

int inicializa_raton (void)
{ union REGS registros; /*Registros del procesador*/
  registros.x.ax=0; /*servicio a ejecutar de la interrupcin 33h*/
  int86(0x33,&registros,&registros); /*ejecucion de la interrupcin*/
  if (!registros.x.ax)
	return -1;

  visualizado=0;
  return registros.x.bx;
}

/***********************************************/
/*Objetivo: Visualiza el raton si esta oculto  */
/*Salida:Pone la varable visualizado a 1       */
/***********************************************/

void visualiza_raton(void)
{ union REGS registros;
  if(!visualizado)
  { registros.x.ax=1;
    int86(0x33,&registros,&registros);
    visualizado=1;
  }
}

/***********************************************/
/*Objetivo:oculta el raton si esta visualizado */
/*salida:pone la variable visualizado a 0      */
/***********************************************/

void oculta_raton(void)
{ union REGS registros;
  if(visualizado)
  { registros.x.ax=2;
    int86(0x33,&registros,&registros);
    visualizado=0;
  }
}

/************************************************/
/*Obj:obtener posic. raton y estado de botones  */
/*sal:valor de la pos. x e y en sus arg.        */
/*  Devuelve el estado de sus botones:          */
/*         bit mas bajo=1 -->pulsado boton izd. */
/*   sig. bit mas bajo=1 -->pulsado boton dcho. */
/*     ambos bit=1 -->ambos estan pulsados.     */
/************************************************/

int lee_raton(int *x,int *y)
{ union REGS registros;
  registros.x.ax=3;
  int86(0x33,&registros,&registros);
  *x=registros.x.cx;
  *y=registros.x.dx;
  return registros.x.bx;
}

/****************************************************/
/*Obj: poner el cursor en una pos.(x,y). concreta   */
/*entrada:dos enteros (x,y)                         */
/****************************************************/

void pon_raton(int x,int y)
{ union REGS registros;
  registros.x.ax=4;
  registros.x.cx=x;
  registros.x.dx=y;
  int86(0x33,&registros,&registros);
}
/****************************************************/
/*  obj:Establece una ventana o recuadro donde se   */
/* puede mover el raton.                            */
/* Entrada: cuatro enteros:Esquina superior izq.    */
/*          e inf. derecha de recuadro deseado      */
/****************************************************/

void limites_raton(int izq, int arriba, int dcha, int abajo)
{ union REGS registros;
  registros.x.ax=7; /*coordenada X*/
  registros.x.cx=izq;
  registros.x.dx=dcha;
  int86(0x33,&registros,&registros);

  registros.x.ax=8; /*coordenada Y*/
  registros.x.cx=arriba;
  registros.x.dx=abajo;
  int86(0x33,&registros,&registros);
}
/*****************************************************/
/*Obj: lee si esta pulsado el boton izq. del raton   */
/*sal: 0 si no esta pulsado. otro valor si lo esta   */
/*tambien se puede saber con la funcion lee_raton    */
/*****************************************************/
char boton_izdo(void)
{ union REGS registros;
  registros.x.ax=3;
  int86(0x33,&registros,&registros);
  return registros.x.bx &1; /*operacion booleana a nivel de bit*/
}
/*****************************************************/
/*Obj: lee si esta pulsado el boton dcho. del raton   */
/*sal: 0 si no esta pulsado. otro valor si lo esta   */
/*tambien se puede saber con la funcion lee_raton    */
/*****************************************************/

char boton_dcho(void)
{ union REGS registros;
  registros.x.ax=3;
  int86(0x33,&registros,&registros);
  return registros.x.bx &2; /*operacion booleana a nivel de bit*/
}
/**************************************************************/
/*Obj: lee si estan pulsado el boton dcho.e izdo. del raton   */
/*sal: 0 si no estan pulsado. otro valor si lo estan          */
/*tambien se puede saber con la funcion lee_raton             */
/**************************************************************/

char dos_botones(void)
{ union REGS registros;
  registros.x.ax=3;
  int86(0x33,&registros,&registros);
  return (registros.x.bx & 2) && (registros.x.bx & 2); /*operacion booleana a nivel de bit*/
}